@@ -9,9 +9,9 @@
 // #include "libKriging/Bench.hpp"
 #include "libKriging/CacheFunction.hpp"
 #include "libKriging/Covariance.hpp"
-#include "libKriging/Kriging.hpp"
 #include "libKriging/KrigingException.hpp"
 #include "libKriging/LinearAlgebra.hpp"
+#include "libKriging/Kriging.hpp"
 #include "libKriging/Optim.hpp"
 #include "libKriging/Random.hpp"
 #include "libKriging/Trend.hpp"
@@ -77,6 +77,8 @@ LIBKRIGING_EXPORT Kriging::Kriging(const arma::colvec& y,
   fit(y, X, regmodel, normalize, optim, objective, parameters);
 }
 
+LIBKRIGING_EXPORT Kriging::Kriging(const Kriging& other, ExplicitCopySpecifier) : Kriging{other} {}
+
 // arma::mat XtX(arma::mat &X) {
 //   arma::mat XtX = arma::zeros(X.n_cols,X.n_cols);
 //   for (arma::uword i = 0; i < X.n_cols; i++) {
@@ -1083,8 +1085,9 @@ LIBKRIGING_EXPORT void Kriging::fit(const arma::colvec& y,
       arma::mat steepest_dX_mean = arma::abs(m_dX) * w;
       // arma::cout << "steepest_dX_mean:" << steepest_dX_mean << arma::endl;
 
-      theta_lower = arma::max(theta_lower, Optim::theta_lower_factor / steepest_dX_mean);
-      theta_upper = arma::min(theta_upper, Optim::theta_upper_factor / steepest_dX_mean);
+      theta_lower = arma::max(theta_lower, Optim::theta_lower_factor * steepest_dX_mean);
+      // no, only relevant for inf bound: theta_upper = arma::min(theta_upper, Optim::theta_upper_factor *
+      // steepest_dX_mean);
       theta_lower = arma::min(theta_lower, theta_upper);
       theta_upper = arma::max(theta_lower, theta_upper);
 
@@ -1652,32 +1655,37 @@ LIBKRIGING_EXPORT std::string Kriging::summary() const {
     });
   };
 
-  oss << "* data";
-  oss << ((m_normalize) ? " (normalized): " : ": ") << m_X.n_rows << "x";
-  arma::rowvec Xmins = arma::min(m_X, 0);
-  arma::rowvec Xmaxs = arma::max(m_X, 0);
-  for (arma::uword i = 0; i < m_X.n_cols; i++) {
-    oss << "[" << Xmins[i] << "," << Xmaxs[i] << "]";
-    if (i < m_X.n_cols - 1)
-      oss << ",";
+  if (m_X.is_empty() || m_X.n_rows == 0) {  // not yet fitted
+    oss << "* covariance:\n";
+    oss << "  * kernel: " << m_covType << "\n";
+  } else {
+    oss << "* data";
+    oss << ((m_normalize) ? " (normalized): " : ": ") << m_X.n_rows << "x";
+    arma::rowvec Xmins = arma::min(m_X, 0);
+    arma::rowvec Xmaxs = arma::max(m_X, 0);
+    for (arma::uword i = 0; i < m_X.n_cols; i++) {
+      oss << "[" << Xmins[i] << "," << Xmaxs[i] << "]";
+      if (i < m_X.n_cols - 1)
+        oss << ",";
+    }
+    oss << " -> " << m_y.n_elem << "x[" << arma::min(m_y) << "," << arma::max(m_y) << "]\n";
+    oss << "* trend " << Trend::toString(m_regmodel);
+    oss << ((m_est_beta) ? " (est.): " : ": ");
+    colvec_printer(m_beta);
+    oss << "\n";
+    oss << "* variance";
+    oss << ((m_est_sigma2) ? " (est.): " : ": ");
+    oss << m_sigma2;
+    oss << "\n";
+    oss << "* covariance:\n";
+    oss << "  * kernel: " << m_covType << "\n";
+    oss << "  * range";
+    oss << ((m_est_theta) ? " (est.): " : ": ");
+    colvec_printer(m_theta);
+    oss << "\n";
+    oss << "  * fit:\n";
+    oss << "    * objective: " << m_objective << "\n";
+    oss << "    * optim: " << m_optim << "\n";
   }
-  oss << " -> " << m_y.n_elem << "x[" << arma::min(m_y) << "," << arma::max(m_y) << "]\n";
-  oss << "* trend " << Trend::toString(m_regmodel);
-  oss << ((m_est_beta) ? " (est.): " : ": ");
-  colvec_printer(m_beta);
-  oss << "\n";
-  oss << "* variance";
-  oss << ((m_est_sigma2) ? " (est.): " : ": ");
-  oss << m_sigma2;
-  oss << "\n";
-  oss << "* covariance:\n";
-  oss << "  * kernel: " << m_covType << "\n";
-  oss << "  * range";
-  oss << ((m_est_theta) ? " (est.): " : ": ");
-  colvec_printer(m_theta);
-  oss << "\n";
-  oss << "  * fit:\n";
-  oss << "    * objective: " << m_objective << "\n";
-  oss << "    * optim: " << m_optim << "\n";
   return oss.str();
 }
